@@ -570,48 +570,6 @@ end
       n n n;
   )
 *)
-module OCaml_402 = struct
-  module Ast = Astlib.Ast_402
-  include Make_witness(Astlib.Ast_402)
-  let version = 402
-  let string_version = "4.02"
-end
-let ocaml_402 : OCaml_402.types ocaml_version = (module OCaml_402)
-module OCaml_403 = struct
-  module Ast = Astlib.Ast_403
-  include Make_witness(Astlib.Ast_403)
-  let version = 403
-  let string_version = "4.03"
-end
-let ocaml_403 : OCaml_403.types ocaml_version = (module OCaml_403)
-module OCaml_404 = struct
-  module Ast = Astlib.Ast_404
-  include Make_witness(Astlib.Ast_404)
-  let version = 404
-  let string_version = "4.04"
-end
-let ocaml_404 : OCaml_404.types ocaml_version = (module OCaml_404)
-module OCaml_405 = struct
-  module Ast = Astlib.Ast_405
-  include Make_witness(Astlib.Ast_405)
-  let version = 405
-  let string_version = "4.05"
-end
-let ocaml_405 : OCaml_405.types ocaml_version = (module OCaml_405)
-module OCaml_406 = struct
-  module Ast = Astlib.Ast_406
-  include Make_witness(Astlib.Ast_406)
-  let version = 406
-  let string_version = "4.06"
-end
-let ocaml_406 : OCaml_406.types ocaml_version = (module OCaml_406)
-module OCaml_407 = struct
-  module Ast = Astlib.Ast_407
-  include Make_witness(Astlib.Ast_407)
-  let version = 407
-  let string_version = "4.07"
-end
-let ocaml_407 : OCaml_407.types ocaml_version = (module OCaml_407)
 module OCaml_408 = struct
   module Ast = Astlib.Ast_408
   include Make_witness(Astlib.Ast_408)
@@ -694,12 +652,6 @@ let ocaml_503 : OCaml_503.types ocaml_version = (module OCaml_503)
 let all_versions : (module OCaml_version) list = [
   (*$foreach_version (fun n _ ->
       printf "(module OCaml_%d : OCaml_version);\n" n)*)
-(module OCaml_402 : OCaml_version);
-(module OCaml_403 : OCaml_version);
-(module OCaml_404 : OCaml_version);
-(module OCaml_405 : OCaml_version);
-(module OCaml_406 : OCaml_version);
-(module OCaml_407 : OCaml_version);
 (module OCaml_408 : OCaml_version);
 (module OCaml_409 : OCaml_version);
 (module OCaml_410 : OCaml_version);
@@ -719,18 +671,6 @@ let all_versions : (module OCaml_version) list = [
     printf "    (Astlib.Migrate_%d_%d)(Astlib.Migrate_%d_%d)\n" a b b a
   )
 *)
-include Register_migration(OCaml_402)(OCaml_403)
-    (Astlib.Migrate_402_403)(Astlib.Migrate_403_402)
-include Register_migration(OCaml_403)(OCaml_404)
-    (Astlib.Migrate_403_404)(Astlib.Migrate_404_403)
-include Register_migration(OCaml_404)(OCaml_405)
-    (Astlib.Migrate_404_405)(Astlib.Migrate_405_404)
-include Register_migration(OCaml_405)(OCaml_406)
-    (Astlib.Migrate_405_406)(Astlib.Migrate_406_405)
-include Register_migration(OCaml_406)(OCaml_407)
-    (Astlib.Migrate_406_407)(Astlib.Migrate_407_406)
-include Register_migration(OCaml_407)(OCaml_408)
-    (Astlib.Migrate_407_408)(Astlib.Migrate_408_407)
 include Register_migration(OCaml_408)(OCaml_409)
     (Astlib.Migrate_408_409)(Astlib.Migrate_409_408)
 include Register_migration(OCaml_409)(OCaml_410)
