@@ -127,21 +127,33 @@ module Default = struct
   let econstruct cd arg =
     pexp_construct ~loc:cd.pcd_loc (Located.map_lident cd.pcd_name) arg
 
-  let rec elist ~loc l =
+  let rec elist_tail ~loc l tail =
     match l with
-    | [] -> pexp_construct ~loc (Located.mk ~loc (Longident.Lident "[]")) None
+    | [] -> tail
     | x :: l ->
         pexp_construct ~loc
           (Located.mk ~loc (Longident.Lident "::"))
-          (Some (pexp_tuple ~loc [ x; elist ~loc l ]))
+          (Some (pexp_tuple ~loc [ x; elist_tail ~loc l tail ]))
 
-  let rec plist ~loc l =
+  let elist ~loc l =
+    let tail =
+      pexp_construct ~loc (Located.mk ~loc (Longident.Lident "[]")) None
+    in
+    elist_tail ~loc l tail
+
+  let rec plist_tail ~loc l tail =
     match l with
-    | [] -> ppat_construct ~loc (Located.mk ~loc (Longident.Lident "[]")) None
+    | [] -> tail
     | x :: l ->
         ppat_construct ~loc
           (Located.mk ~loc (Longident.Lident "::"))
-          (Some (ppat_tuple ~loc [ x; plist ~loc l ]))
+          (Some (ppat_tuple ~loc [ x; plist_tail ~loc l tail ]))
+
+  let plist ~loc l =
+    let tail =
+      ppat_construct ~loc (Located.mk ~loc (Longident.Lident "[]")) None
+    in
+    plist_tail ~loc l tail
 
   let unapplied_type_constr_conv_without_apply ~loc (ident : Longident.t) ~f =
     match ident with
@@ -386,6 +398,8 @@ end) : S = struct
   let eapply e el = Default.eapply ~loc e el
   let eabstract ps e = Default.eabstract ~loc ps e
   let esequence el = Default.esequence ~loc el
+  let elist_tail l tail = Default.elist_tail ~loc l tail
+  let plist_tail l tail = Default.plist_tail ~loc l tail
   let elist l = Default.elist ~loc l
   let plist l = Default.plist ~loc l
 
